@@ -5,5 +5,5 @@ string ClearTextMail::mailCommand(string const &recipient) const
     return
         "/usr/bin/mail -s '" + subject() + "' "
                 "-a \"Reply-To: " + d_replyTo + "\" " +
-                headers() + " " + recipient;
+                headers(processHeaders) + " " + recipient;
 }
